@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installCheckenvWidgetContainer.php 706 2008-06-09 05:32:41Z fishbone $
+ * @version    SVN: $Id: _installCheckenvWidgetContainer.php 809 2008-06-30 06:55:28Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -179,7 +179,27 @@ class _installCheckenvWidgetContainer extends BaseWidgetContainer
 		}
 		$this->tmpl->addVar("_widget","current_access", $data);
 		
+		// クッキーの使用
+		$data = '<b><font color="green">on</font></b>';
+		$this->tmpl->addVar("_widget","config_sess_use_cookies", $data);
+		if (ini_get('session.use_cookies')){
+			$data = '<b><font color="green">on</font></b>';
+		} else {
+			$data = '<b><font color="red">off</font></b>';
+		}
+		$this->tmpl->addVar("_widget","current_sess_use_cookies", $data);
+		
 		// ##### セッション関係 #####
+		// セッションIDの自動付加
+		$data = '<b><font color="green">off</font></b>';
+		$this->tmpl->addVar("_widget","config_sess_use_trans_sid", $data);
+		if (ini_get('session.use_trans_sid')){
+			$data = '<b><font color="red">on</font></b>';
+		} else {
+			$data = '<b><font color="green">off</font></b>';
+		}
+		$this->tmpl->addVar("_widget","current_sess_use_trans_sid", $data);
+		
 		// セッション起動
 		$data = '<b><font color="green">off</font></b>';
 		$this->tmpl->addVar("_widget","config_sess_auto_start", $data);
