@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id$
+ * @version    SVN: $Id: blog_mainDb.php 690 2008-06-04 08:25:07Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -591,7 +591,45 @@ class blog_mainDb extends BaseDb
 			$queryStr .=    'AND be_language_id = ? ';
 			$this->selectLoop($queryStr, array(2, $entryId, $langId), $callback, null);		// 「公開」(2)データを表示
 		}
-	}	
+	}
+	/**
+	 * エントリー項目をカテゴリー指定で取得(表示用)
+	 *
+	 * @param int		$categoryId			カテゴリーID
+	 * @param int 		$itemCount			取得項目数(0のときは該当すべて)
+	 * @param string	$langId				言語
+	 * @param int		$order				取得順(0=昇順,1=降順)
+	 * @param function	$callback			コールバック関数
+	 * @return 			なし
+	 */
+	function getEntryItemsByCategory($categoryId, $itemCount, $langId, $order, $callback)
+	{
+		$offset = 0;// ページングの際使用
+		$params = array();
+		$queryStr = 'SELECT distinct(be_serial) FROM blog_entry RIGHT JOIN blog_entry_with_category ON be_serial = bw_entry_serial ';
+		$queryStr .=  'WHERE be_language_id = ? '; $params[] = $langId;
+		$queryStr .=    'AND be_deleted = false ';		// 削除されていない
+		$queryStr .=    'AND be_status = ? '; $params[] = 2;	// 「公開」(2)データ
+		$queryStr .=    'AND bw_category_id = ? '; $params[] = $categoryId;// 記事カテゴリー
+		
+		// シリアル番号を取得
+		$serialArray = array();
+		$ret = $this->selectRecords($queryStr, $params, $serialRows);
+		if ($ret){
+			for ($i = 0; $i < count($serialRows); $i++){
+				$serialArray[] = $serialRows[$i]['be_serial'];
+			}
+		}
+		$serialStr = implode(',', $serialArray);
+		if (empty($serialStr)) $serialStr = '0';	// 0レコードのときはダミー値を設定
+	
+		$queryStr = 'SELECT * FROM blog_entry ';
+		$queryStr .=  'WHERE be_serial in (' . $serialStr . ') ';
+		$ord = '';
+		if (!empty($order)) $ord = 'DESC ';
+		$queryStr .=  'ORDER BY be_regist_dt ' . $ord . 'LIMIT ' . $itemCount . ' offset ' . $offset;		// 投稿順
+		$this->selectLoop($queryStr, array(), $callback, null);
+	}
 	/**
 	 * すべての言語を取得
 	 *
